==> healthrian_common_support-1.1.8.tar.gz: lib/src/lead_state/lead_state.dart <==
// ignore_for_file: public_member_api_docs, non_constant_identifier_names

import 'package:copy_with_extension/copy_with_extension.dart';

part 'lead_state.g.dart';

@CopyWith()
class LeadState {
  LeadState({
    required bool ra,
    required bool rl,
    required bool la,
    required bool ll,
    required bool v1,
    required bool v2,
    required bool v3,
    required bool v4,
    required bool v5,
    required bool v6,
  }) : list = [ra, rl, la, ll, v1, v2, v3, v4, v5, v6];

  static bool _checkBit(int value, int bit) => (value & (1 << bit)) == 0;

  LeadState.fromBytes(int high, int low)
      : list = [
          _checkBit(high, 1),
          true,
          _checkBit(low, 2),
          _checkBit(low, 1),
          _checkBit(low, 7),
          _checkBit(low, 3),
          _checkBit(low, 4),
          _checkBit(low, 5),
          _checkBit(low, 6),
          _checkBit(low, 0)
        ];

  LeadState.empty()
      : list = [
          false,
          true,
          false,
          false,
          false,
          false,
          false,
          false,
          false,
          false,
        ];

  final List<bool> list;

  bool get ra => list[0];

  bool get rl => list[1];

  bool get la => list[2];

  bool get ll => list[3];

  bool get v1 => list[4];

  bool get v2 => list[5];

  bool get v3 => list[6];

  bool get v4 => list[7];

  bool get v5 => list[8];

  bool get v6 => list[9];

  bool get isAttached => !list.contains(false);

  bool get isDetached => list.contains(false);

  @deprecated
  List<bool> toList() => list;
}

==> healthrian_common_support-1.18.0.tar.gz: lib/src/lead_state/lead_state.dart <==
// ignore_for_file: public_member_api_docs, non_constant_identifier_names

import 'package:copy_with_extension/copy_with_extension.dart';

part 'lead_state.g.dart';

@CopyWith()
class LeadState {
  LeadState({
    required bool ra,
    required bool rl,
    required bool la,
    required bool ll,
    required bool v1,
    required bool v2,
    required bool v3,
    required bool v4,
    required bool v5,
    required bool v6,
  }) : list = [ra, rl, la, ll, v1, v2, v3, v4, v5, v6];

  static bool _checkBit(int value, int bit) => (value & (1 << bit)) == 0;

  LeadState.fromBytes(int state1, int state2)
      : list = [
          _checkBit(state1, 1), //ra
          true, //rl
          _checkBit(state2, 1), //la
          _checkBit(state2, 2), //ll
          _checkBit(state2, 7), //v1
          _checkBit(state2, 3), //v2
          _checkBit(state2, 4), //v3
          _checkBit(state2, 5), //v4
          _checkBit(state2, 6), //v5
          _checkBit(state2, 0) //v6
        ];

  LeadState.empty()
      : list = [
          false,
          true,
          false,
          false,
          false,
          false,
          false,
          false,
          false,
          false,
        ];

  final List<bool> list;

  bool get ra => list[0];

  bool get rl => list[1];

  bool get la => list[2];

  bool get ll => list[3];

  bool get v1 => list[4];

  bool get v2 => list[5];

  bool get v3 => list[6];

  bool get v4 => list[7];

  bool get v5 => list[8];

  bool get v6 => list[9];

  bool get isAttached => !list.contains(false);

  bool get isDetached => list.contains(false);

  @deprecated
  List<bool> toList() => list;

  @override
  String toString() {
    return 'LeadState(ra:$ra, rl:$rl, la:$la, ll:$ll, '
        'v1:$v1, v2:$v2, v3:$v3, v4:$v4, v5:$v5, v6:$v6)';
  }
}
